@@ -7,7 +7,7 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 
-from shift_detector_connector.shift_definition import ShiftAnalyzeResult
+from shift_detector_connector.shift_analyze_result import ShiftAnalyzeResult
 from shift_detector_connector.shift_detector_connector import ShiftDetectorConnector
 from detector_connector import DetectorHttpConnector as ShiftDetectorHttpConnector
 from shift_detector_connector.shift_detector_kafka_connector import ShiftDetectorKafkaConnector
